
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.4.post2',
    'branch_nick': '(HEAD',
    'revision_id': 'fe5bfc246f0508fa5967e9048eeeb3078e61732b',
    'revno': 8457
}
